@@ -1,4 +1,4 @@
-__version__ = (0, 11)
+__version__ = (0, 12)
 
 import email.utils
 import hashlib
@@ -27,9 +27,9 @@ class UploadCareException(Exception):
 
 class UploadCare(UploaderMixin):
     def __init__(self, pub_key, secret, timeout=5,
-                 api_base='http://api.uploadcare.com/',
-                 upload_base='http://upload.uploadcare.com/',
-                 cdn_base='http://ucarecdn.com/',
+                 api_base='https://api.uploadcare.com/',
+                 upload_base='https://upload.uploadcare.com/',
+                 cdn_base='https://ucarecdn.com/',
                  verify_api_ssl=True,
                  verify_upload_ssl=True,
                  custom_headers=None,
